@@ -24,9 +24,7 @@ class RelationshipBuilder(object):
         ]
 
         return sa.exists(
-            sa.select(
-                [1]
-            ).where(
+            sa.select(1).where(
                 sa.and_(
                     getattr(remote_alias, tx_column) <=
                     getattr(obj, tx_column),
@@ -48,7 +46,7 @@ class RelationshipBuilder(object):
         tx_column = option(obj, 'transaction_column_name')
         reflector = VersionExpressionReflector(obj, self.property)
         subquery = sa.select(
-            [sa.func.max(getattr(self.remote_cls, tx_column))]
+            sa.func.max(getattr(self.remote_cls, tx_column))
         ).where(
             sa.and_(
                 getattr(self.remote_cls, tx_column) <=
@@ -56,10 +54,7 @@ class RelationshipBuilder(object):
                 reflector(self.property.primaryjoin)
             )
         )
-        try:
-            subquery = subquery.scalar_subquery()
-        except AttributeError:  # SQLAlchemy < 1.4
-            subquery = subquery.as_scalar()
+        subquery = subquery.scalar_subquery()
 
         return getattr(self.remote_cls, tx_column) == subquery
 
@@ -276,9 +271,7 @@ class RelationshipBuilder(object):
         ]
 
         association_exists = sa.exists(
-            sa.select(
-                [1]
-            ).where(
+            sa.select(1).where(
                 sa.and_(
                     association_table_alias.c[tx_column] <=
                     getattr(obj, tx_column),
@@ -296,9 +289,7 @@ class RelationshipBuilder(object):
             ).correlate(self.association_version_table)
         )
         return sa.exists(
-            sa.select(
-                [1]
-            ).where(
+            sa.select(1).where(
                 sa.and_(
                     reflector(self.property.primaryjoin),
                     association_exists,
