@@ -392,10 +392,10 @@ def count_versions(obj):
         '%s = %r' % (pk, getattr(obj, pk))
         for pk in get_primary_keys(obj)
     ]
-    query = 'SELECT COUNT(1) FROM %s WHERE %s' % (
+    query = sa.text('SELECT COUNT(1) FROM %s WHERE %s' % (
         table_name,
         ' AND '.join(criteria)
-    )
+    ))
     return session.execute(query).scalar()
 
 
